Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2011-05-28 08:53:17 +0400
committerCampbell Barton <ideasman42@gmail.com>2011-05-28 08:53:17 +0400
commit20ae95422e9af2c1d3f927d932a20459f2387cac (patch)
treef616911c136ff4e3e9efd0130d3b85d80c594885 /build_files
parentd580ae10873ad149ca73902b69f389aad8976419 (diff)
include ffmpeg_compat header in cmake source list.
Diffstat (limited to 'build_files')
-rw-r--r--build_files/cmake/macros.cmake44
1 files changed, 24 insertions, 20 deletions
diff --git a/build_files/cmake/macros.cmake b/build_files/cmake/macros.cmake
index 45dc67f9ce6..6e4aaa51a49 100644
--- a/build_files/cmake/macros.cmake
+++ b/build_files/cmake/macros.cmake
@@ -13,19 +13,13 @@ macro(blender_include_dirs
include_directories(${all_incs})
endmacro()
-# only MSVC uses SOURCE_GROUP
-macro(blender_add_lib_nolist
- name
- sources
- includes)
-
- # message(STATUS "Configuring library ${name}")
- blender_include_dirs("${includes}")
- add_library(${name} ${sources})
+macro(blender_source_group
+ sources)
# Group by location on disk
source_group("Source Files" FILES CMakeLists.txt)
+
foreach(SRC ${sources})
get_filename_component(SRC_EXT ${SRC} EXT)
if(${SRC_EXT} MATCHES ".h" OR ${SRC_EXT} MATCHES ".hpp")
@@ -36,16 +30,26 @@ macro(blender_add_lib_nolist
endforeach()
endmacro()
-# # works fine but having the includes listed is helpful for IDE's (QtCreator/MSVC)
-# macro(blender_add_lib_nolist
-# name
-# sources
-# includes)
-#
-# message(STATUS "Configuring library ${name}")
-# include_directories(${includes})
-# add_library(${name} ${sources})
-# endmacro()
+
+# only MSVC uses SOURCE_GROUP
+macro(blender_add_lib_nolist
+ name
+ sources
+ includes)
+
+ # message(STATUS "Configuring library ${name}")
+
+ # include_directories(${includes})
+ blender_include_dirs("${includes}")
+
+ add_library(${name} ${sources})
+
+ # works fine without having the includes
+ # listed is helpful for IDE's (QtCreator/MSVC)
+ blender_source_group("${sources}")
+
+endmacro()
+
macro(blender_add_lib
name
@@ -55,9 +59,9 @@ macro(blender_add_lib
blender_add_lib_nolist(${name} "${sources}" "${includes}")
set_property(GLOBAL APPEND PROPERTY BLENDER_LINK_LIBS ${name})
-
endmacro()
+
macro(SETUP_LIBDIRS)
# see "cmake --help-policy CMP0003"
if(COMMAND cmake_policy)